@@ -85,11 +85,13 @@ ArticleViewerWebEngine::ArticleViewerWebEngine(KActionCollection *ac, QWidget *p
     mPageEngine = new ArticleViewerWebEnginePage(profile, this);
     profile->setPersistentCookiesPolicy(QWebEngineProfile::ForcePersistentCookies);
 
-#if QTWEBENGINEWIDGETS_VERSION < QT_VERSION_CHECK(5, 13, 0)
     // Needed to workaround crash in webengine, see https://bugreports.qt.io/browse/QTBUG-72260
     auto webEngineUrlInterceptor = new AkregatorRequestInterceptor();
     connect(profile, &QObject::destroyed, webEngineUrlInterceptor, &AkregatorRequestInterceptor::deleteLater);
+#if QTWEBENGINEWIDGETS_VERSION < QT_VERSION_CHECK(5, 13, 0)
     profile->setRequestInterceptor(webEngineUrlInterceptor);
+#else
+    profile->setUrlRequestInterceptor(webEngineUrlInterceptor);
 #endif
 
     setPage(mPageEngine);
